@@ -1,10 +1,12 @@
 import logging
 import os
+import sys
 from logging import handlers
 from os import environ
 from os import path
 
 import yaml
+from flask_restful import Resource
 
 
 class Config:
@@ -149,10 +151,28 @@ class Config:
         ch = logging.StreamHandler()
         ch.setLevel(console_log_level)
         # create formatter and add it to the handlers
-        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(funcName)s - %(message)s')
+        formatter = logging.Formatter('%(asctime)s - %(threadName)s - %(name)s - %(levelname)s - %(funcName)s - %(message)s')
         fh.setFormatter(formatter)
         ch.setFormatter(formatter)
         # add the handlers to the logger
         logger.addHandler(fh)
         logger.addHandler(ch)
         return logger
+
+
+class Version(Resource):
+
+    def __init__(self, **kwargs):
+        if getattr(sys, 'frozen', False):
+            # pyinstaller lets you copy files to arbitrary locations under the _MEIPASS root dir
+            root = os.path.join(sys._MEIPASS, 'ui')
+        else:
+            root = os.path.dirname(__file__)
+        v_name = os.path.join(root, 'VERSION')
+        self.__v = 'UNKNOWN'
+        if os.path.exists(v_name):
+            with open(v_name, 'r') as f:
+                self.__v = f.read()
+
+    def get(self):
+        return {'version': self.__v}
\ No newline at end of file
